# Presentations
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/presentations#overview)
  * [Creating a Presentation](https://help.sap.com/docs/leanix/ea/presentations#creating-a-presentation)
  * [Adding Notes to Slides](https://help.sap.com/docs/leanix/ea/presentations#adding-notes-to-slides)
  * [Adding, Rearranging, and Deleting Slides](https://help.sap.com/docs/leanix/ea/presentations#adding,-rearranging,-and-deleting-slides)
  * [Changing Permissions for Reports and Diagrams](https://help.sap.com/docs/leanix/ea/presentations#changing-permissions-for-reports-and-diagrams)
  * [Previewing and Starting a Presentation](https://help.sap.com/docs/leanix/ea/presentations#previewing-and-starting-a-presentation)
  * [Presentation Details](https://help.sap.com/docs/leanix/ea/presentations#presentation-details)
  * [Presentation Permissions](https://help.sap.com/docs/leanix/ea/presentations#presentation-permissions)


View all
Use presentations to share enterprise architecture insights from reports and diagrams with your organization, without the need to export data to external presentation tools.
